==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/de.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Datenschutz",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Das Zentrum für Datenschutz zeigt Ihnen, wo Ihre Daten gespeichert werden und wer darauf Zugriff hat. Egal ob Sie Daten freigegeben haben oder es Administratoren sind.",
    "Remove external admin" : "Externen Administrator entfernen",
    "Add external admin" : "Einen externen Administrator hinzufügen",
    "Name of external admin" : "Name des externen Administrators",
    "This server is using full-disk-encryption." : "Dieser Server verwendet Festplattenverschlüsselung.",
    "Your files are not protected by encryption." : "Deine Dateien sind nicht mittels Verschlüsselung geschützt.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Deine Dateien sind mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt.",
    "This server is protected with full-disk-encryption." : "Dieser Server ist mittels Festplattenverschlüsselung geschützt.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Deine Dateien sind mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt. Ausserdem ist dieser Server mittels Festplattenverschlüsselung geschützt.",
    "Your data is located in: " : "Deine Daten befinden sich in: ",
    "The admin hasn't selected the location of the server yet." : "Der Administrator hat den Standort des Servers noch nicht ausgewählt.",
    "Change data location" : "Datenspeicherort ändern",
    "Please select a region" : "Bitte eine Region auswählen",
    "You don't have any shares with individual users." : "Du teilst keine Dateien mit einzelnen Nutzern.",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Vereinigte Arabische Emirate",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua und Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentinien",
    "American Samoa" : "Amerikanisch-Samoa",
    "Austria" : "Österreich",
    "Australia" : "Australien",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Inseln",
    "Azerbaijan" : "Aserbaidschan",
    "Bosnia and Herzegovina" : "Bosnien und Herzegowina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesch",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivien",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Saba und Sint Eustatius",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvetinsel",
    "Botswana" : "Botswana",
    "Belarus" : "Weißrussland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosinseln",
    "Democratic Republic of the Congo" : "Kongo",
    "Central African Republic" : "Zentralafrikanische Republik",
    "Congo" : "Kongo",
    "Switzerland" : "Schweiz",
    "Cote d'Ivoire" : "Elfenbeinküste",
    "Cook Islands" : "Cookinseln",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "China",
    "Colombia" : "Kolumbien",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Weihnachtsinsel",
    "Cyprus" : "Zypern",
    "Czech" : "Tschechisch",
    "Germany" : "Deutschland",
    "Djibouti" : "Dschibuti",
    "Denmark" : "Dänemark",
    "Dominican Republic" : "Dominikanische Republik",
    "Algeria" : "Algerien",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estland",
    "Egypt" : "Ägypten",
    "West Sahara" : "Westsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Äthiopien",
    "Finland" : "Finnland",
    "Fiji" : "Fidschi",
    "Falkland Islands" : "Falklandinseln",
    "Micronesia" : "Mikronesien",
    "Faroe Islands" : "Färöer",
    "France" : "Frankreich",
    "Gabon" : "Gabun",
    "United Kingdom" : "Vereinigtes Königreich",
    "Grenada" : "Grenada",
    "Georgia" : "Georgien",
    "French Guiana" : "Französisch-Guinea",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Äquatorialguinea",
    "Greece" : "Griechenland",
    "South Georgia and the South Sandwich Islands" : "Südgeorgien und die Südlichen Sandwichinseln",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hongkong",
    "Heard Island and McDonald Islands" : "Heard und die McDonaldinseln",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "Indien",
    "British Indian Ocean Territory" : "Britisches Territorium im Indischen Ozean",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodscha",
    "Kiribati" : "Kiribati",
    "Comores" : "Komoren",
    "Saint Kitts and Nevis" : "St. Kitts und Nevis",
    "North Korea" : "Nordkorea",
    "South Korea" : "Südkorea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Kaimaninseln",
    "Kazakhstan" : "Kasachstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "St. Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Lybien",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Moldova" : "Moldawien",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "St. Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshallinseln",
    "Macedonia" : "Mazedonien",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolei",
    "Macao" : "Macau",
    "Northern Mariana Islands" : "Nördliche Marianen",
    "Mauritania" : "Mauretanien",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediven",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Neukaledonien",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkinsel",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Niederlande",
    "Norway" : "Norwegen",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Neuseeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Französisch-Polynesien",
    "Papua New Guinea" : "Papua-Neuguinea",
    "Philippines" : "Philippinen",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint-Pierre und Miquelon",
    "Pitcairn" : "Pitcairninseln",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palästina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russia" : "Russland",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudiarabien",
    "Solomon Islands" : "Salomonen",
    "Seychelles" : "Seychellen",
    "Sudan" : "Sudan",
    "Sweden" : "Schweden",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "St. Helena, Ascension und Tristan da Cunha",
    "Slovenia" : "Slowenien",
    "Svalbard and Jan Mayen" : "Spitzbergen und Jan Mayen",
    "Slovakia" : "Slowakei",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Südsudan",
    "Sao Tome and Principe" : "São Tomé und Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syrien",
    "Swaziland" : "Swasiland",
    "Turks and Caicos Islands" : "Turks- und Caicosinseln",
    "Chad" : "Tschad",
    "Fr. S. Antarctic Lands" : "Französische Süd- und Antarktisgebiete",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadschikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Osttimor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunesien",
    "Tonga" : "Tonga",
    "Turkey" : "Türkei",
    "Trinidad and Tobago" : "Trinidad und Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tansania",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States" : "Vereinigte Staaten von Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Usbekistan",
    "Holy See" : "Vatikanstadt",
    "Saint Vincent and the Grenadines" : "St. Vincent und die Grenadinen",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Jungferninseln (Britisch)",
    "Virgin Islands (U.S.)" : "Jungferninseln (U.S.)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis und Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Südafrika",
    "Zambia" : "Sambia",
    "Zimbabwe" : "Simbabwe",
    "Your Nextcloud account" : "Dein Nextcloud Konto",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Deine Daten repräsentieren, wer Du bist und können leicht missbraucht werden. Wir von Nextcloud glauben, dass Du das Recht hast zu entscheiden, was mit Deinen Daten geschieht. Nextcloud schützt Deine Rechte gemäß dem Benutzerdatenmanifest!",
    "User Data Manifesto 2.0" : "Benutzer-Daten-Manifest 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definition von Grundrechten für Menschen zur Kontrolle ihrer eigenen Daten im Internetzeitalter",
    "Control" : "Kontrolle",
    "over user data access" : "über den Zugriff auf Benutzerdaten",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Daten, die explizit und bereitwillig von einem Benutzer hochgeladen werden, sollten unter der endgültigen Kontrolle des Benutzers stehen. Die Benutzer sollten entscheiden können, wer direkten Zugriff auf ihre Daten gewährt und mit welchen Berechtigungen und Lizenzen dieser Zugriff gewährt werden soll.",
    "Knowledge" : "Wissenswertes",
    "of how the data is stored" : "wie die Daten gespeichert werden",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Wenn die Daten zu einem bestimmten Dienstanbieter hochgeladen werden, sollten die Benutzer darüber informiert werden, wo dieser bestimmte Dienstanbieter die Daten speichert, wie lange, in welcher Rechtsordnung der jeweilige Dienstanbieter tätig ist und welche Gesetze gelten.",
    "Freedom" : "Freiheit",
    "to choose a platform" : "eine Plattform zu wählen",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Benutzer sollten jederzeit in der Lage sein, ihre Daten aus dem Dienst zu extrahieren, ohne dass es zu einer Herstellerbindung kommt. Um dies zu gewährleisten, sind offene Standards für Formate und Protokolle notwendig.",
    "Learn more ↗" : "Erfahre mehr ↗",
    "Where is your data?" : "Wo befinden sich Deine Daten?",
    "Who has access to your data?" : "Wer hat Zugriff auf Deine Daten?",
    "Administrators" : "Administratoren",
    "People you shared with" : "Menschen, mit denen Du geteilt hast",
    "Privacy policy" : "Datenschutz",
    "Read the privacy policy." : "Lese hier die Datenschutzerklärung.",
    "Encryption" : "Verschlüsselung",
    "Please select a country" : "Bitte wähle ein Land",
    "Bosnia and Herzegowina" : "Bosnien und Herzegowina"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/de.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Datenschutz",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Das Zentrum für Datenschutz zeigt Ihnen, wo Deine Daten gespeichert werden und wer darauf Zugriff hat. Egal ob Du Daten freigegeben hast oder es Administratoren sind.",
    "Remove external admin" : "Externen Administrator entfernen",
    "Add external admin" : "Einen externen Administrator hinzufügen",
    "Name of external admin" : "Name des externen Administrators",
    "This server is using full-disk-encryption." : "Dieser Server verwendet Festplattenverschlüsselung.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Dein Speicher ist mit einem Hauptschlüssel mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Deine Dateien auf externen Speichern können mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose}  und einem Hauptschlüssel verschlüsselt werden.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Dein Speicher ist mit einem individuellen Benutzerschlüssel mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Deine Dateien auf externen Speichern können mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose}  und einem individuellen Benutzerschlüssel verschlüsselt werden.",
    "Additionally, this server is protected with full-disk-encryption." : "Zusätzlich ist dieser Server mit einer Festplattenverschlüsselung geschützt.",
    "This server is protected with full-disk-encryption." : "Dieser Server ist mittels Festplattenverschlüsselung geschützt.",
    "Your files are not protected by encryption." : "Deine Dateien sind nicht mittels Verschlüsselung geschützt.",
    "Your data is located in:" : "Deine Daten befinden sich in: ",
    "The admin hasn't selected the location of the server yet." : "Der Administrator hat den Standort des Servers noch nicht ausgewählt.",
    "Change data location" : "Datenspeicherort ändern",
    "Please select a region" : "Bitte eine Region auswählen",
    "You don't have any shares with individual users." : "Du teilst keine Dateien mit einzelnen Nutzern.",
    "Somaliland" : "Somaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Vereinigte Arabische Emirate",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua und Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentinien",
    "American Samoa" : "Amerikanisch-Samoa",
    "Austria" : "Österreich",
    "Australia" : "Australien",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Inseln",
    "Azerbaijan" : "Aserbaidschan",
    "Bosnia and Herzegovina" : "Bosnien und Herzegowina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesch",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivien",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Saba und Sint Eustatius",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvetinsel",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosinseln",
    "Democratic Republic of the Congo" : "Kongo",
    "Central African Republic" : "Zentralafrikanische Republik",
    "Congo" : "Kongo",
    "Switzerland" : "Schweiz",
    "Cote d'Ivoire" : "Elfenbeinküste",
    "Cook Islands" : "Cookinseln",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "China",
    "Colombia" : "Kolumbien",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Weihnachtsinsel",
    "Cyprus" : "Zypern",
    "Czech" : "Tschechisch",
    "Germany" : "Deutschland",
    "Djibouti" : "Dschibuti",
    "Denmark" : "Dänemark",
    "Dominican Republic" : "Dominikanische Republik",
    "Algeria" : "Algerien",
    "Ecuador" : "Ekuador",
    "Estonia" : "Estland",
    "Egypt" : "Ägypten",
    "West Sahara" : "Westsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Äthiopien",
    "Finland" : "Finnland",
    "Fiji" : "Fidschi",
    "Falkland Islands" : "Falklandinseln",
    "Micronesia" : "Mikronesien",
    "Faroe Islands" : "Färöer",
    "France" : "Frankreich",
    "Gabon" : "Gabun",
    "United Kingdom" : "Vereinigtes Königreich",
    "Grenada" : "Grenada",
    "Georgia" : "Georgien",
    "French Guiana" : "Französisch-Guinea",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Äquatorialguinea",
    "Greece" : "Griechenland",
    "South Georgia and the South Sandwich Islands" : "Südgeorgien und die Südlichen Sandwichinseln",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hongkong",
    "Heard Island and McDonald Islands" : "Heard und die McDonaldinseln",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "Indien",
    "British Indian Ocean Territory" : "Britisches Territorium im Indischen Ozean",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodscha",
    "Kiribati" : "Kiribati",
    "Comores" : "Komoren",
    "Saint Kitts and Nevis" : "St. Kitts und Nevis",
    "North Korea" : "Nordkorea",
    "South Korea" : "Südkorea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Kaimaninseln",
    "Kazakhstan" : "Kasachstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "St. Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Libyen",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Moldova" : "Moldawien",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "St. Martin",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshallinseln",
    "Macedonia" : "Mazedonien",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolei",
    "Macao" : "Macau",
    "Northern Mariana Islands" : "Nördliche Marianen",
    "Mauritania" : "Mauretanien",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediven",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Neukaledonien",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkinsel",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Niederlande",
    "Norway" : "Norwegen",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Neuseeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Französisch-Polynesien",
    "Papua New Guinea" : "Papua-Neuguinea",
    "Philippines" : "Philippinen",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint-Pierre und Miquelon",
    "Pitcairn" : "Pitcairninseln",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palästina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russia" : "Russland",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudi-Arabien",
    "Solomon Islands" : "Salomonen",
    "Seychelles" : "Seychellen",
    "Sudan" : "Sudan",
    "Sweden" : "Schweden",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "St. Helena, Ascension und Tristan da Cunha",
    "Slovenia" : "Slowenien",
    "Svalbard and Jan Mayen" : "Spitzbergen und Jan Mayen",
    "Slovakia" : "Slowakei",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Südsudan",
    "Sao Tome and Principe" : "São Tomé und Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syrien",
    "Swaziland" : "Swasiland",
    "Turks and Caicos Islands" : "Turks- und Caicosinseln",
    "Chad" : "Tschad",
    "Fr. S. Antarctic Lands" : "Französische Süd- und Antarktisgebiete",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadschikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Osttimor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunesien",
    "Tonga" : "Tonga",
    "Turkey" : "Türkei",
    "Trinidad and Tobago" : "Trinidad und Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tansania",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States" : "Vereinigte Staaten von Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Usbekistan",
    "Holy See" : "Vatikanstadt",
    "Saint Vincent and the Grenadines" : "St. Vincent und die Grenadinen",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Jungferninseln (britisch)",
    "Virgin Islands (U.S.)" : "Jungferninseln (U.S.)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis und Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Südafrika",
    "Zambia" : "Sambia",
    "Zimbabwe" : "Simbabwe",
    "Your Nextcloud account" : "Dein Nextcloud Konto",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Deine Daten repräsentieren, wer Du bist und können leicht missbraucht werden. Wir von Nextcloud glauben, dass Du das Recht hast zu entscheiden, was mit Deinen Daten geschieht. Nextcloud schützt Deine Rechte gemäß dem Benutzerdatenmanifest!",
    "User Data Manifesto 2.0" : "Benutzer-Daten-Manifest 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definition von Grundrechten für Menschen zur Kontrolle ihrer eigenen Daten im Internetzeitalter",
    "Control" : "Kontrolle",
    "over user data access" : "über den Zugriff auf Benutzerdaten",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Daten, die explizit und bereitwillig von einem Benutzer hochgeladen werden, sollten unter der endgültigen Kontrolle des Benutzers stehen. Die Benutzer sollten entscheiden können, wer direkten Zugriff auf ihre Daten gewährt und mit welchen Berechtigungen und Lizenzen dieser Zugriff gewährt werden soll.",
    "Knowledge" : "Wissenswertes",
    "of how the data is stored" : "wie die Daten gespeichert werden",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Wenn die Daten zu einem bestimmten Dienstanbieter hochgeladen werden, sollten die Benutzer darüber informiert werden, wo dieser bestimmte Dienstanbieter die Daten speichert, wie lange, in welcher Rechtsordnung der jeweilige Dienstanbieter tätig ist und welche Gesetze gelten.",
    "Freedom" : "Freiheit",
    "to choose a platform" : "eine Plattform zu wählen",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Benutzer sollten jederzeit in der Lage sein, ihre Daten aus dem Dienst zu extrahieren, ohne dass es zu einer Herstellerbindung kommt. Um dies zu gewährleisten, sind offene Standards für Formate und Protokolle notwendig.",
    "Learn more ↗" : "Erfahre mehr ↗",
    "Where is your data?" : "Wo befinden sich Deine Daten?",
    "Who has access to your data?" : "Wer hat Zugriff auf Deine Daten?",
    "Administrators" : "Administratoren",
    "People you shared with" : "Menschen, mit denen Du geteilt hast",
    "Privacy policy" : "Datenschutz",
    "Read the privacy policy." : "Lese hier die Datenschutzerklärung.",
    "Encryption" : "Verschlüsselung",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Deine Dateien sind mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Deine Dateien sind mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose} verschlüsselt. Ausserdem ist dieser Server mittels Festplattenverschlüsselung geschützt.",
    "Your data is located in: " : "Deine Daten befinden sich in: "
},
"nplurals=2; plural=(n != 1);");
